pub struct FailureInfo {
pub error_message: String,
pub root_cause_actor: String,
pub root_cause_name: Option<String>,
pub occurred_at: String,
pub is_propagated: bool,
}Expand description
Structured failure information for failed actors.
Fields
error_message: Stringroot_cause_actor: Stringroot_cause_name: Option<String>occurred_at: Stringis_propagated: boolTrait Implementations
Sourceimpl Clone for FailureInfo
impl Clone for FailureInfo
Sourcefn clone(&self) -> FailureInfo
fn clone(&self) -> FailureInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FailureInfo
impl Debug for FailureInfo
Sourceimpl<'de> Deserialize<'de> for FailureInfo
impl<'de> Deserialize<'de> for FailureInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FailureInfo
impl JsonSchema for FailureInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Named for FailureInfo
impl Named for FailureInfo
Sourcefn typename() -> &'static str
fn typename() -> &'static str
The globally unique type name for the type.
This should typically be the fully qualified Rust name of the type.
Sourcefn typehash() -> u64
fn typehash() -> u64
A globally unique hash for this type.
TODO: actually enforce perfect hashing
Sourcefn typeid() -> TypeId
fn typeid() -> TypeId
The TypeId for this type. TypeIds are unique only within a binary,
and should not be used for global identification.
Sourcefn port() -> u64
fn port() -> u64
The globally unique port for this type. Typed ports are in the range
of 1<<63..1<<64-1.
Sourceimpl PartialEq for FailureInfo
impl PartialEq for FailureInfo
Sourceimpl Serialize for FailureInfo
impl Serialize for FailureInfo
impl StructuralPartialEq for FailureInfo